Creates a layer which is the subset of points lying on the hull (convex or alpha) of the set of points specified.
Usage
l_layer_hull(
widget,
x,
y,
color = "black",
linewidth = 1,
label = "hull",
parent = "root",
index = 0,
group = NULL,
active = TRUE,
...
)
Value
an l_layer widget
Arguments
widget
`loon` widget path name as a string
x
The coordinates of x. See details
y
The coordinates of y. See details
color
the line color of each hull
linewidth
the line width
label
label used in the layers inspector
parent
parent group layer
index
of the newly added layer in its parent group
group
separate x vector or y vector into a list by group
active
a logical determining whether points appear or not (default is TRUE for all points).
If a logical vector is given of length equal to the number of points,
then it identifies which points appear (TRUE) and which do not (FALSE).
...
other arguments to modify l_layer_line.
Details
Coordinates: the x or y can be a list or a vector.
If they are vectors, the argument group will be used to set the groups.
If they are not provided, the x will be inherited from the widget