l_layer_trails(
widget,
x,
y,
xpre,
ypre,
color = "black",
linewidth = 1,
label = "trails",
parent = "root",
index = 0,
active = TRUE,
...
)
Value
an l_layer widget
Arguments
widget
`loon` widget path name as a string
x
The coordinates of x representing the current state
y
The coordinates of y representing the current state
xpre
the same length of x representing the last state
ypre
the same length of y representing the last state
color
the color of the trail
linewidth
the line width
label
label used in the layers inspector
parent
parent group layer
index
of the newly added layer in its parent group
active
a logical determining whether points appear or not (default is TRUE for all points).
If a logical vector is given of length equal to the number of points,
then it identifies which points appear (TRUE) and which do not (FALSE).